@@ -1,7 +1,6 @@
 """Provides an atom class. Serves as a basis for most other modules"""
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
@@ -11,7 +10,7 @@ from scipy import constants
 from os.path import normcase, join, split
 
 
-class Atom:
+class Atom(object):
     """Atom class
     Holds the basic information - name, mass, Lennard-Jones epsilon and sigma parameters, and the formation energy.
 
