@@ -2,7 +2,6 @@
 a basis for most other modules"""
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
@@ -12,8 +11,8 @@ from scipy import constants
 from os.path import normcase, split, join
 
 
-class Molecule:
-    """Molecule class for a multi-temperature approximation
+class Molecule_sts(object):
+    """Molecule class for a state-to-state approximation
     Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
     dissociation-related partition functions, etc.
 
@@ -46,33 +45,11 @@ class Molecule:
     current_rot_dimless - array containing the current dimensionless rotational energies
     current_vibr_dimless - array containing the current dimensionless vibrational energies
     current_T - current temperature of the mixture
-    current_T1 - current vibrational temperature of the particular molecular species
     current_Z_rot - current rotational partition function
-    current_Z_vibr - current vibrational partition function
-    current_n - current numeric density of the particular species
-    current_ni - aray containing the current densities of the particular species at each vibrational level
-    current_v_exp - array containing the current vibrational exponents
-    current_w - current average amount of vibrational quanta of the particular species
-    current_wdt - current derivative of average amount of vibrational quanta per unit of mass of the particular species
-    with respect to the temperature T
-    current_wdt1 - current derivative of average amount of vibrational quanta per unit of mass of the particular species
-    with respect to the vibrational temperature T1
-    current_edt - current derivative of vibrational energy per unit of mass of the particular species
-    with respect to the temperature T
-    current_edt1 - current derivative of vibrational energy per unit of mass of the particular species
-    with respect to the vibrational temperature T1
-    current_zdt - current derivative of vibrational partition function with respect to the temperature T
-    current_zdt1 - current derivative of vibrational partition function with respect to the vibrational temperature T1
-    current_vae - current vibrational energy averaged over the vibrational spectrum
-    current_vae_dim - current dimensionless vibrational energy averaged over the vibrational spectrum
     current_rae - current rotational energy averaged over the rotational spectrum
     current_rae_dim - current dimensionless rotational energy averaged over the rotational spectrum
-    current_vaesq - current squared vibrational energy averaged over the vibrational spectrum
-    current_vaesq_dim - current squared dimensionless vibrational energy averaged over the vibrational spectrum
     current_raesq - current squared rotational energy averaged over the rotational spectrum
     current_raesq_dim - current squared dimensionless rotational energy averaged over the rotational spectrum
-    current_vae - current value of i * vibrational_energy(i) averaged over the vibrational spectrum
-    current_vae_dim - current value of i * dimensionless_vibrational_energy(i) averaged over the vibrational spectrum
     """
     def __init__(self, name, vmodel='anharmonic'):
         self.name = name
@@ -102,31 +79,12 @@ class Molecule:
         self.crot = constants.k / self.mass
 
         self.current_rot_dimless = np.zeros(self.num_rot + 1)
-
         self.current_T = 1.0
-        self.current_T1 = 1.0
         self.current_Z_rot = 0.0
-        self.current_Z_vibr = 0.0
-        self.current_n = 0.0
-        self.current_ni = np.zeros(self.num_vibr + 1)
-        self.current_v_exp = np.zeros(self.num_vibr + 1)
-        self.current_w = 0.0
-        self.current_wdt = 0.0
-        self.current_wdt1 = 0.0
-        self.current_edt = 0.0
-        self.current_edt1 = 0.0
-        self.current_zdt = 0.0
-        self.current_zdt1 = 0.0
-        self.current_vae = 0.0
-        self.current_vae_dim = 0.0
         self.current_rae = 0.0
         self.current_rae_dim = 0.0
-        self.current_vaesq = 0.0
-        self.current_vaesq_dim = 0.0
         self.current_raesq = 0.0
         self.current_raesq_dim = 0.0
-        self.current_vae_i = 0.0
-        self.current_vae_i_dim = 0.0
 
         a = np.arange(0, self.num_vibr + 1, 1)
         if self.vibr_model == 'table':
@@ -156,7 +114,7 @@ class Molecule:
         for j in xrange(self.num_rot + 1):
             self.rot[j] = j * (j + 1) * self.rot_const
 
-    def renorm(self, T, T1, n_c):
+    def renorm_sts(self, T):
         """Calculates all current values for the molecule
 
         Returns:
@@ -167,46 +125,14 @@ class Molecule:
         T1 - the vibrational temperature of the molecular species
         n - the numeric density of the species in question
         """
-        if T < T1:
-            if self.avc == 0.0:
-                treanor_i_star = self.num_vibr
-            else:
-                treanor_i_star = int(0.5 + self.vibr_energy(1, 1) * T / (2 * self.avc * self.hvc * T1))
-        else:
-            treanor_i_star = int(0.5 + self.vibr_energy(1, 1) * T / (2 * self.avc * self.hvc * T1))
-        if self.max_vibr > treanor_i_star:
-            self.num_vibr = treanor_i_star
-        else:
-            self.num_vibr = self.max_vibr
-
         self.current_Z_rot = self.Z_rot(T)
-        self.current_Z_vibr = self.Z_vibr(T, T1)
         self.current_rot_dimless = self.rot / (constants.k * T)
         self.current_vibr_dimless = self.vibr / (constants.k * T)
-        self.current_vae_dim = self.avg_vibr_energy(T, T1, 1)
-        self.current_vae = self.avg_vibr_energy(T, T1, 0)
-        self.current_rae_dim = self.avg_rot_energy(T, 1)
         self.current_rae = self.avg_rot_energy(T, 0)
-        self.current_vaesq = self.avg_vibr_energy_sq(T, T1, 0)
-        self.current_vaesq_dim = self.avg_vibr_energy_sq(T, T1, 1)
+        self.current_rae_dim = self.avg_rot_energy(T, 1)
         self.current_raesq = self.avg_rot_energy_sq(T, 0)
         self.current_raesq_dim = self.avg_rot_energy_sq(T, 1)
-        self.current_w = self.avg_i(T, T1)
-        self.current_wdt = self.W_dT(T, T1)
-        self.current_wdt1 = self.W_dT1(T, T1)
-        self.current_edt = self.E_vibr_dT(T, T1)
-        self.current_edt1 = self.E_vibr_dT1(T, T1)
-        self.current_zdt = self.Z_vibr_dT(T, T1)
-        self.current_zdt1 = self.Z_vibr_dT1(T, T1)
-        self.current_vae_i = self.avg_vibr_energy_i(T, T1, 0)
-        self.current_vae_i_dim = self.avg_vibr_energy_i(T, T1, 1)
-
-        a = np.arange(0, self.num_vibr + 1, 1)
-        self.current_v_exp = self.vibr_exp(a, T, T1)
-        self.current_ni = self.ni(a, T, T1, n_c)
-        self.current_n = n_c
         self.current_T = T
-        self.current_T1 = T1
 
     def num_vibr_levels(self, true_amt=True):
         """Returns amount of vibrational levels (either the maximum one or current one)
@@ -307,24 +233,6 @@ class Molecule:
         else:
             return self.current_vibr_dimless[i] + self.current_rot_dimless[j]
 
-    def vibr_exp(self, i, T, T1):
-        """Returns the vibrational exponent: exp(-(vibr_energy(i) - i * vibr_energy(1)) / kT - i * vibr_energy(1) /
-        kT1)
-
-        Returns:
-        The vibrational exponent
-
-        Takes as input:
-        i - vibrational level (may be an np.array of indices, result will then be an array)
-        T - the temperature of the mixture
-        T1 - the vibrational temperature of the molecular species
-        """
-        if (self.current_T != T) or (self.current_T1 != T1):
-            return np.exp(-(self.vibr[i] - i * self.vibr[1]) / (T * constants.k)
-                          - i * self.vibr[1] / (T1 * constants.k))
-        else:
-            return self.current_v_exp[i]
-
     def rot_exp(self, j, T):
         """Returns the rotational exponent: (2j + 1) * exp(-rot_energy(j) / kT), (2j + 1) being the degeneracy
         of the j-th rotational state
@@ -336,22 +244,7 @@ class Molecule:
         j - rotational level (may be an np.array of indices, result will then be an array)
         T - the temperature of the mixture
         """
-        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (constants.k * T))
-
-    def Z_vibr(self, T, T1):
-        """Returns the vibrational partition function Z_vibr(T, T1)
-
-        Returns:
-        The vibrational partition function
-
-        Takes as input:
-        T - the temperature of the mixture
-        T1 - the vibrational temperature of the molecular species
-        """
-        if (self.current_T != T) or (self.current_T1 != T1):
-            return self.vibr_exp(np.arange(0, self.num_vibr + 1, 1), T, T1).sum()
-        else:
-            return self.current_Z_vibr
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (self.rot_symmetry * constants.k * T))
 
     def Z_rot(self, T):
         """Returns the rotational partition function Z_rot(T)
@@ -387,6 +280,264 @@ class Molecule:
         else:
             return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
 
+    def avg_rot_energy_sq(self, T, dim=1):
+        """Returns the squared rotational energy, averaged over the rotational spectrum
+         (either dimensional or dimensionless)
+
+        Returns:
+        The averaged sqaured rotational energy
+
+        Takes as input:
+        T - the temperature of the mixture
+        dim - if equal to 1, returns the dimensional energy; otherwise, returns the
+        dimensionless energy
+        """
+        if self.current_T != T:
+            kT = constants.k * T
+            B = self.rot_const / kT
+            snr = self.num_rot * (self.num_rot + 1)
+            if dim == 1:
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
+                                                                                                * self.Z_rot(T) * B)
+            else:
+                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
+                                                                                    * self.Z_rot(T) * B)
+        else:
+            if dim == 1:
+                return self.current_raesq_dim
+            else:
+                return self.current_raesq
+
+    def Z_vibr_eq(self, T, model='none'):
+        """Returns the equilibrium vibrational partition function (which is used in various
+        dissociation models) as a function of the temperature T and a parameter U ('model'). If U is equal to 0,
+        the result is just the equilibirum partition function (except that the the vibrational energy
+        at the zero level is not equal to zero); otherwise, the parameter U is used instead of the temperature T
+
+        Returns:
+        The equilibrium vibrational partition function (either as a function of T or as a function of U)
+
+        Takes as input:
+        T - the temperature of the mixture
+        model - multiple options:
+            if equal to 'none', Z_vibr_eq returns simply the equilibrium vibrational partition function
+            if equal to 'inf', Z_vibr_eq returns Z_vibr_eq(-infinity, 0)
+            if equal to 'D6k', Z_vibr_eq returns Z_vibr_eq(-D / 6k, 0), where D is the dissociation energy of the
+                               molecule
+            if equal to '3T', Z_vibr_eq returns Z_vibr_eq(-3T, 0)
+        """
+
+        if model == 'none':
+            return np.sum(np.exp(-(self.vibr_zero + self.vibr) / (T * constants.k)))
+        elif model == 'inf':
+            res = 0.0
+            for i in xrange(self.num_vibr + 1):
+                res += 1.0
+            return res
+        elif model == 'D6k':
+            return np.sum(np.exp(6.0 * ((self.vibr + self.vibr_zero) / self.diss)))
+        elif model == '3T':
+            return np.sum(np.exp((self.vibr_zero + self.vibr) / (3.0 * constants.k * T)))
+
+    def Z_diss(self, i, T, model='D6k'):
+        """Returns the non-equilibrium factor (which is used in various
+        dissociation models) as a function of the temperature T and a parameter U ('model') and
+        the vibrational level i, which is equal to
+        Z_equilibrium(T) * exp(vibr_energy(i) * (1 / T + 1 / U) / k) / Z_equilibrium(-U)
+
+        Returns:
+        The non-equilibrium factor
+
+        Takes as input:
+        i - the vibrational level (from which the molecule dissociates)
+        T - the temperature of the mixture
+        model - U is equal to infiinity if model == 'inf'; U = Diss_energy / 6k if model == 'D6k';
+        U = 3 * T if model == '3T'.
+        model - multiple options:
+            if equal to 'inf', U is equal to infinity
+            if equal to 'D6k', U is equal to D / 6k, where D is the dissociation energy of the molecule
+            if equal to '3T', U is equal to 3T
+        """
+        if model == 'inf':
+            return np.exp((self.vibr[i] + self.vibr_zero) / (T * constants.k))\
+                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+        elif model == 'D6k':
+            return np.exp((self.vibr[i] + self.vibr_zero) * (1.0 / (constants.k * T) + 6.0 / self.diss))\
+                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+        elif model == '3T':
+            return np.exp((self.vibr[i] + self.vibr_zero) / (0.75 * T * constants.k)) \
+                                * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+
+
+class Molecule(Molecule_sts):
+    """Molecule class for a multi-temperature approximation
+    Provides various methods such as averaged rotational and vibrational energies, vibrational exponents,
+    dissociation-related partition functions, etc.
+
+    Class Fields:
+    name - name ('N2', 'O2', etc.)
+    vibr_model - multiple options, model of vibrational energy:
+        'harmonic' - a harmonic oscillator model
+        'anharmonic' - an anharmonic oscillator model
+        'table' - for table values of vibrational energy (if available in a separate file)
+    mass - the mass
+    num_rot - amount of rotational levels
+    num_vibr - amount of vibrational levels (may change depending on T and T1)
+    max_vibr - maximum amount of vibrational levels (during initialization this field and num_vibr are equal)
+    inertia - moment of rotational inertia
+    rot_const - h ^ 2 / (8 * (pi ^ 2) * inertia), used for rotational energies
+    hvc - harmonicity coefficient, for vibrational energies
+    avc - anharmonicity coefficient, for vibrational energies
+    diss - dissociation energy
+    LJe - the Lennard-Jones epsilon parameter
+    LJs - the Lennard-Jones sigma parameter
+    rot - array of rotational energies
+    vibr - array of vibrational energies
+    vibr_zero - vibrational energy of the 0-th vibrational level (since the Treanor distribution requires the energy
+    of the 0th level to be considered equal to 0, the real value has to be stored separately)
+    crot - specific heat capacity of rotational degrees of freedom, calculated as crot = k / molecule.mass
+
+    All the following fields (i.e. fields which name starts with "current") are initially set to 0.0 or 1.0, and
+    then updated each time the renorm method is called. They are used to store various values which depend
+    on T, T1 and the numeric density of the mixture, so as to avoid calculating them twice in a row
+    current_rot_dimless - array containing the current dimensionless rotational energies
+    current_vibr_dimless - array containing the current dimensionless vibrational energies
+    current_T - current temperature of the mixture
+    current_T1 - current vibrational temperature of the particular molecular species
+    current_Z_rot - current rotational partition function
+    current_Z_vibr - current vibrational partition function
+    current_n - current numeric density of the particular species
+    current_ni - aray containing the current densities of the particular species at each vibrational level
+    current_v_exp - array containing the current vibrational exponents
+    current_w - current average amount of vibrational quanta of the particular species
+    current_wdt - current derivative of average amount of vibrational quanta per unit of mass of the particular species
+    with respect to the temperature T
+    current_wdt1 - current derivative of average amount of vibrational quanta per unit of mass of the particular species
+    with respect to the vibrational temperature T1
+    current_edt - current derivative of vibrational energy per unit of mass of the particular species
+    with respect to the temperature T
+    current_edt1 - current derivative of vibrational energy per unit of mass of the particular species
+    with respect to the vibrational temperature T1
+    current_zdt - current derivative of vibrational partition function with respect to the temperature T
+    current_zdt1 - current derivative of vibrational partition function with respect to the vibrational temperature T1
+    current_vae - current vibrational energy averaged over the vibrational spectrum
+    current_vae_dim - current dimensionless vibrational energy averaged over the vibrational spectrum
+    current_rae - current rotational energy averaged over the rotational spectrum
+    current_rae_dim - current dimensionless rotational energy averaged over the rotational spectrum
+    current_vaesq - current squared vibrational energy averaged over the vibrational spectrum
+    current_vaesq_dim - current squared dimensionless vibrational energy averaged over the vibrational spectrum
+    current_raesq - current squared rotational energy averaged over the rotational spectrum
+    current_raesq_dim - current squared dimensionless rotational energy averaged over the rotational spectrum
+    current_vae - current value of i * vibrational_energy(i) averaged over the vibrational spectrum
+    current_vae_dim - current value of i * dimensionless_vibrational_energy(i) averaged over the vibrational spectrum
+    """
+    def __init__(self, name, vmodel='anharmonic'):
+        Molecule_sts.__init__(name, vmodel)
+
+        self.current_T1 = 1.0
+        self.current_Z_vibr = 0.0
+        self.current_n = 0.0
+        self.current_ni = np.zeros(self.num_vibr + 1)
+        self.current_v_exp = np.zeros(self.num_vibr + 1)
+        self.current_w = 0.0
+        self.current_wdt = 0.0
+        self.current_wdt1 = 0.0
+        self.current_edt = 0.0
+        self.current_edt1 = 0.0
+        self.current_zdt = 0.0
+        self.current_zdt1 = 0.0
+        self.current_vae = 0.0
+        self.current_vae_dim = 0.0
+        self.current_vaesq = 0.0
+        self.current_vaesq_dim = 0.0
+        self.current_vae_i = 0.0
+        self.current_vae_i_dim = 0.0
+
+    def renorm(self, T, T1, n_c):
+        """Calculates all current values for the molecule
+
+        Returns:
+        nothing
+
+        Takes as input:
+        T - the temperature of the mixture
+        T1 - the vibrational temperature of the molecular species
+        n - the numeric density of the species in question
+        """
+        if T < T1:
+            if self.avc == 0.0:
+                treanor_i_star = self.num_vibr
+            else:
+                treanor_i_star = int(0.5 + self.vibr_energy(1, 1) * T / (2 * self.avc * self.hvc * T1))
+        else:
+            treanor_i_star = int(0.5 + self.vibr_energy(1, 1) * T / (2 * self.avc * self.hvc * T1))
+        if self.max_vibr > treanor_i_star:
+            self.num_vibr = treanor_i_star
+        else:
+            self.num_vibr = self.max_vibr
+
+        self.current_Z_rot = self.Z_rot(T)
+        self.current_Z_vibr = self.Z_vibr(T, T1)
+        self.current_rot_dimless = self.rot / (constants.k * T)
+        self.current_vibr_dimless = self.vibr / (constants.k * T)
+        self.current_vae_dim = self.avg_vibr_energy(T, T1, 1)
+        self.current_vae = self.avg_vibr_energy(T, T1, 0)
+        self.current_rae_dim = self.avg_rot_energy(T, 1)
+        self.current_rae = self.avg_rot_energy(T, 0)
+        self.current_vaesq = self.avg_vibr_energy_sq(T, T1, 0)
+        self.current_vaesq_dim = self.avg_vibr_energy_sq(T, T1, 1)
+        self.current_raesq = self.avg_rot_energy_sq(T, 0)
+        self.current_raesq_dim = self.avg_rot_energy_sq(T, 1)
+        self.current_w = self.avg_i(T, T1)
+        self.current_wdt = self.W_dT(T, T1)
+        self.current_wdt1 = self.W_dT1(T, T1)
+        self.current_edt = self.E_vibr_dT(T, T1)
+        self.current_edt1 = self.E_vibr_dT1(T, T1)
+        self.current_zdt = self.Z_vibr_dT(T, T1)
+        self.current_zdt1 = self.Z_vibr_dT1(T, T1)
+        self.current_vae_i = self.avg_vibr_energy_i(T, T1, 0)
+        self.current_vae_i_dim = self.avg_vibr_energy_i(T, T1, 1)
+
+        a = np.arange(0, self.num_vibr + 1, 1)
+        self.current_v_exp = self.vibr_exp(a, T, T1)
+        self.current_ni = self.ni(a, T, T1, n_c)
+        self.current_n = n_c
+        self.current_T = T
+        self.current_T1 = T1
+
+    def vibr_exp(self, i, T, T1):
+        """Returns the vibrational exponent: exp(-(vibr_energy(i) - i * vibr_energy(1)) / kT - i * vibr_energy(1) /
+        kT1)
+
+        Returns:
+        The vibrational exponent
+
+        Takes as input:
+        i - vibrational level (may be an np.array of indices, result will then be an array)
+        T - the temperature of the mixture
+        T1 - the vibrational temperature of the molecular species
+        """
+        if (self.current_T != T) or (self.current_T1 != T1):
+            return np.exp(-(self.vibr[i] - i * self.vibr[1]) / (T * constants.k)
+                          - i * self.vibr[1] / (T1 * constants.k))
+        else:
+            return self.current_v_exp[i]
+
+    def Z_vibr(self, T, T1):
+        """Returns the vibrational partition function Z_vibr(T, T1)
+
+        Returns:
+        The vibrational partition function
+
+        Takes as input:
+        T - the temperature of the mixture
+        T1 - the vibrational temperature of the molecular species
+        """
+        if (self.current_T != T) or (self.current_T1 != T1):
+            return self.vibr_exp(np.arange(0, self.num_vibr + 1, 1), T, T1).sum()
+        else:
+            return self.current_Z_vibr
+
     def avg_vibr_energy(self, T, T1, dim=1):
         """Returns the vibrational energy, averaged over the vibrational spectrum (either dimensional or dimensionless)
 
@@ -444,34 +595,6 @@ class Molecule:
             else:
                 return self.current_vaesq
 
-    def avg_rot_energy_sq(self, T, dim=1):
-        """Returns the squared rotational energy, averaged over the rotational spectrum
-         (either dimensional or dimensionless)
-
-        Returns:
-        The averaged sqaured rotational energy
-
-        Takes as input:
-        T - the temperature of the mixture
-        dim - if equal to 1, returns the dimensional energy; otherwise, returns the
-        dimensionless energy
-        """
-        if self.current_T != T:
-            kT = constants.k * T
-            B = self.rot_const / kT
-            snr = self.num_rot * (self.num_rot + 1)
-            if dim == 1:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
-                                                                                                * self.Z_rot(T) * B)
-            else:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
-                                                                                    * self.Z_rot(T) * B)
-        else:
-            if dim == 1:
-                return self.current_raesq_dim
-            else:
-                return self.current_raesq
-
     def avg_i(self, T, T1):
         """Returns the average amount of vibrational quanta (returns the quantity i averaged over
          the vibrational spectrum)
@@ -532,66 +655,6 @@ class Molecule:
             else:
                 return self.current_vae_i
 
-    def Z_vibr_eq(self, T, model='none'):
-        """Returns the equilibrium vibrational partition function (which is used in various
-        dissociation models) as a function of the temperature T and a parameter U ('model'). If U is equal to 0,
-        the result is just the equilibirum partition function (except that the the vibrational energy
-        at the zero level is not equal to zero); otherwise, the parameter U is used instead of the temperature T
-
-        Returns:
-        The equilibrium vibrational partition function (either as a function of T or as a function of U)
-
-        Takes as input:
-        T - the temperature of the mixture
-        model - multiple options:
-            if equal to 'none', Z_vibr_eq returns simply the equilibrium vibrational partition function
-            if equal to 'inf', Z_vibr_eq returns Z_vibr_eq(-infinity, 'none')
-            if equal to 'D6k', Z_vibr_eq returns Z_vibr_eq(-D / 6k, 'none'), where D is the dissociation energy of the
-                               molecule
-            if equal to '3T', Z_vibr_eq returns Z_vibr_eq(-3T, 'none')
-        """
-
-        if model == 'none':
-            return np.sum(np.exp(-(self.vibr_zero + self.vibr) / (T * constants.k)))
-        elif model == 'inf':
-            res = 0.0
-            for i in xrange(self.num_vibr + 1):
-                res += 1.0
-            return res
-        elif model == 'D6k':
-            return np.sum(np.exp(6.0 * ((self.vibr + self.vibr_zero) / self.diss)))
-        elif model == '3T':
-            return np.sum(np.exp((self.vibr_zero + self.vibr) / (3.0 * constants.k * T)))
-
-    def Z_diss(self, i, T, model='D6k'):
-        """Returns the non-equilibrium factor (which is used in various
-        dissociation models) as a function of the temperature T and a parameter U ('model') and
-        the vibrational level i, which is equal to
-        Z_equilibrium(T) * exp(vibr_energy(i) * (1 / T + 1 / U) / k) / Z_equilibrium(-U)
-
-        Returns:
-        The non-equilibrium factor
-
-        Takes as input:
-        i - the vibrational level (from which the molecule dissociates)
-        T - the temperature of the mixture
-        model - U is equal to infiinity if model == 'inf'; U = Diss_energy / 6k if model == 'D6k';
-        U = 3 * T if model == '3T'.
-        model - multiple options:
-            if equal to 'inf', U is equal to infinity
-            if equal to 'D6k', U is equal to D / 6k, where D is the dissociation energy of the molecule
-            if equal to '3T', U is equal to 3T
-        """
-        if model == 'inf':
-            return np.exp((self.vibr[i] + self.vibr_zero) / (T * constants.k))\
-                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
-        elif model == 'D6k':
-            return np.exp((self.vibr[i] + self.vibr_zero) * (1.0 / (constants.k * T) + 6.0 / self.diss))\
-                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
-        elif model == '3T':
-            return np.exp((self.vibr[i] + self.vibr_zero) / (0.75 * T * constants.k)) \
-                                * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
-
     def ni(self, i, T, T1, n_c):
         """Returns the numeric density at the i-th vibrational level for the molecular species, using
         the Treanor distribution for an anharmonic oscillator (or a harmonic one)
