@@ -3,7 +3,6 @@ TODO - definition rotrel fix
 """
 __author__ = 'George Oblapenko'
 __license__ = "GPL"
-__version__ = "0.3.5"
 __maintainer__ = "George Oblapenko"
 __email__ = "kunstmord@kunstmord.com"
 __status__ = "Production"
@@ -68,7 +67,7 @@ def Zr(T, idata, mass, infcoll, model='VSS'):
     return mass * infcoll / (2.0 * div * idata[0])
 
 
-def rot_rel_time(T, idata, n, infcoll, model='IPL'):
+def rot_rel_time(T, idata, molecule, n, infcoll, model='IPL'):
     """
     Calculates the rotational relaxation time using Parker's formula and \Omega^{(2,2)} integral
 
@@ -78,6 +77,7 @@ def rot_rel_time(T, idata, n, infcoll, model='IPL'):
     Takes as input:
     T - the temperature of the mixture
     idata - collision data for the species involved
+    molecule - the molecule being considered
     n - the numeric density of the mixture
     infcoll - zeta_{\inf} parameter
     model - model used to calculate the Omega integral:
@@ -88,7 +88,7 @@ def rot_rel_time(T, idata, n, infcoll, model='IPL'):
         'Switch' - returns result for LJ model when T / eps < 10 and for IPL model otherwise; eps is the Lennard-Jones
                    parameter
     """
-    return 0.15625 * constants.pi * Zr_original(T, idata[2], infcoll) * constants.pi\
+    return 0.15625 * constants.pi * Zr_original(T, molecule.LJe, infcoll) * constants.pi\
         / (n * omega(T, 2, 2, idata, model=model, nokt=False))  # 0.15625 is 5 / 32
 
 
